'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styled = require('styled-components');
var styled__default = _interopDefault(styled);

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  }
}

function _iterableToArray(iter) {
  if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance");
}

var pxRe = /-?\d*[.\d]*px/g;
var base64Re = /^data:\w+\/[a-zA-Z+\-.]+;base64,/i;

var px2vw = function px2vw(px) {
  return Number(px) ? "".concat(Math.round(Number(px) / 7.5 * 100000) / 100000, "vw") : 0;
};

var convertStringPx2vw = function convertStringPx2vw(style) {
  return style.replace(pxRe, function (value) {
    return px2vw(value.replace('px', ''));
  });
};

var convertInterpolationPx2vw = function convertInterpolationPx2vw(interpolation) {
  if (typeof interpolation !== 'function') return interpolation;
  return function (props) {
    var result = interpolation(props);

    if (result && !base64Re.test(result) // 非base64字符串
    && pxRe.test(result)) {
      // 包含px单位
      if (typeof result === 'string') {
        return convertStringPx2vw(result);
      }

      if (Array.isArray(result)) {
        return result.map(convertStringPx2vw);
      }
    }

    return result;
  };
};

var withCss = function withCss(styled$$1) {
  var interleave = function interleave(strings) {
    for (var _len = arguments.length, interpolations = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      interpolations[_key - 1] = arguments[_key];
    }

    strings = strings.map(convertStringPx2vw);
    interpolations = interpolations.map(convertInterpolationPx2vw);
    return styled$$1.apply(void 0, [strings].concat(_toConsumableArray(interpolations)));
  };

  Object.keys(styled$$1).forEach(function (prop) {
    return interleave[prop] = withTemplateFunc(styled$$1[prop]);
  });
  return interleave;
};

var withTemplateFunc = function withTemplateFunc(styled$$1) {
  return function () {
    return withCss(styled$$1.apply(void 0, arguments));
  };
};

var styledPx2vw = function (styled$$1) {
  var obj = withTemplateFunc(styled$$1);
  Object.keys(styled$$1).forEach(function (key) {
    obj[key] = withCss(styled$$1[key]);
    Object.keys(styled$$1[key]).forEach(function (prop) {
      return obj[key][prop] = withTemplateFunc(styled$$1[key][prop]);
    });
  });
  return obj;
}(styled__default);

Object.keys(styled).forEach(function (key) { exports[key] = styled[key]; });
exports.default = styledPx2vw;
exports.px2vw = px2vw;
